pub async fn forward_http(
request: CopilotHttpRequest,
) -> Result<CopilotHttpResponse, CopilotRequestError>Expand description
Forward an HTTP request to its real upstream and stream the response back.
This is the default behaviour of CopilotRequestHandler::send_request;
consumers that mutate a request can call it to forward the mutated request.