pub struct SessionRpcHistory<'a> { /* private fields */ }Expand description
session.history.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcHistory<'a>
impl<'a> SessionRpcHistory<'a>
Sourcepub async fn compact(&self) -> Result<HistoryCompactResult, Error>
pub async fn compact(&self) -> Result<HistoryCompactResult, Error>
Wire method: session.history.compact.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn truncate(
&self,
params: HistoryTruncateRequest,
) -> Result<HistoryTruncateResult, Error>
pub async fn truncate( &self, params: HistoryTruncateRequest, ) -> Result<HistoryTruncateResult, Error>
Wire method: session.history.truncate.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.