SessionRpcMode

Struct SessionRpcMode 

pub struct SessionRpcMode<'a> { /* private fields */ }
session.mode.* RPCs.

Implementations

Source

impl<'a> SessionRpcMode<'a>

pub async fn get(&self) -> Result<SessionMode, Error>

Gets the current agent interaction mode.

Wire method: session.mode.get.

Returns

The session mode the agent is operating in

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn set(&self, params: ModeSetRequest) -> Result<(), Error>

Sets the current agent interaction mode.

Wire method: session.mode.set.

Parameters
  • params - Agent interaction mode to apply to the session.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.