pub struct SessionRpcQueue<'a> { /* private fields */ }Expand description
session.queue.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcQueue<'a>
impl<'a> SessionRpcQueue<'a>
Sourcepub async fn pending_items(&self) -> Result<QueuePendingItemsResult, Error>
pub async fn pending_items(&self) -> Result<QueuePendingItemsResult, Error>
Returns the local session’s pending user-facing queued items and steering messages.
Wire method: session.queue.pendingItems.
Returns
Snapshot of the session’s pending queued items and immediate-steering messages.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn remove_most_recent(
&self,
) -> Result<QueueRemoveMostRecentResult, Error>
pub async fn remove_most_recent( &self, ) -> Result<QueueRemoveMostRecentResult, Error>
Removes the most recently queued user-facing item (LIFO).
Wire method: session.queue.removeMostRecent.
Returns
Indicates whether a user-facing pending item was removed.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn clear(&self) -> Result<(), Error>
pub async fn clear(&self) -> Result<(), Error>
Clears all pending queued items on the local session.
Wire method: session.queue.clear.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.