SessionRpcTelemetry

Struct SessionRpcTelemetry 

pub struct SessionRpcTelemetry<'a> { /* private fields */ }
session.telemetry.* RPCs.

Implementations

Source

impl<'a> SessionRpcTelemetry<'a>

pub async fn set_feature_overrides( &self, params: TelemetrySetFeatureOverridesRequest, ) -> Result<(), Error>

Sets feature override key/value pairs to attach to subsequent telemetry events for the session.

Wire method: session.telemetry.setFeatureOverrides.

Parameters
  • params - Feature override key/value pairs to attach to subsequent telemetry events from this session.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.