CustomAgentsUpdatedAgent

Struct CustomAgentsUpdatedAgent 

pub struct CustomAgentsUpdatedAgent {
    pub description: String,
    pub display_name: String,
    pub id: String,
    pub model: Option<String>,
    pub name: String,
    pub source: String,
    pub tools: Vec<String>,
    pub user_invocable: bool,
}

Fields

description: String

Description of what the agent does

display_name: String

Human-readable display name

id: String

Unique identifier for the agent

model: Option<String>

Model override for this agent, if set

name: String

Internal name of the agent

source: String

Source location: user, project, inherited, remote, or plugin

tools: Vec<String>

List of tool names available to this agent, or null when all tools are available

user_invocable: bool

Whether the agent can be selected by the user