pub struct SessionSnapshotRewindData {
pub events_removed: f64,
pub up_to_event_id: String,
}Expand description
Session rewind details including target event and count of removed events
Fields
events_removed: f64Number of events that were removed by the rewind
up_to_event_id: StringEvent ID that was rewound to; this event and all after it were removed