pub struct GitHubToken { /* private fields */ }Expand description
A GitHub access token returned by a session token provider.
expires_in_seconds is the positive remaining lifetime when the callback
completes. Production GitHub tokens typically last eight hours.
Implementations
Sourceimpl GitHubToken
impl GitHubToken