DenyAllHandler

Struct DenyAllHandler 

pub struct DenyAllHandler;
A SessionHandler that denies all permission requests and otherwise relies on the trait’s default fallback responses for every other event (e.g. tool invocations return “unhandled”, elicitations cancel, plan-mode prompts decline). This is the safe default used when no handler is set on SessionConfig::handler — sessions will not stall on permission prompts (they’re denied immediately) but no privileged actions will be taken without an explicit opt-in.