Module resolve

Module resolve 

GitHub Copilot CLI binary resolution (env var, embedded, PATH search).

Enums

BinarySource
How the copilot binary was resolved.

Functions

copilot_binary
Find the copilot CLI binary on the system.
copilot_binary_on_path
Find the copilot CLI binary using only the current PATH entries.
copilot_binary_with_source
Like copilot_binary but also reports how the binary was resolved.
extended_path
Build an extended PATH by prepending extra dirs to the standard search paths (current PATH + common install locations).