pub fn copilot_binary_with_source() -> Result<(PathBuf, BinarySource), Error>Expand description
Like copilot_binary but also reports how the binary was resolved.
pub fn copilot_binary_with_source() -> Result<(PathBuf, BinarySource), Error>Like copilot_binary but also reports how the binary was resolved.