pub enum AdaptiveThinkingSupport {
Unsupported,
Optional,
Required,
Unknown,
}Expand description
Resolved Anthropic adaptive-thinking capability for a model.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Unsupported
The model does not accept thinking.type=‘adaptive’
Optional
The model accepts adaptive thinking but also accepts thinking.type=‘enabled’
Required
The model only accepts adaptive thinking and rejects thinking.type=‘enabled’ with HTTP 400 (e.g. opus-4.7/4.8)
Unknown
Unknown variant for forward compatibility.