pub enum BuiltinToolFormatType {
Grammar,
Unknown,
}Expand description
Custom input-format kind.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Grammar
The tool input is parsed with the supplied grammar.
Unknown
Unknown variant for forward compatibility.