pub enum CatalogMcpServerInstallability {
Installable,
NotInstallablePolicy,
Unknown,
}Expand description
Whether an MCP server candidate can be planned for installation
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Installable
An install plan can be computed for this MCP server candidate.
NotInstallablePolicy
Policy forbids installing this MCP server candidate.
Unknown
Unknown variant for forward compatibility.