pub enum CatalogTrustSnapshotMalformedStatus {
Malformed,
Unknown,
}Expand description
The trust field was empty, unbounded, or had the wrong JSON type.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Malformed
The trust field was empty, unbounded, or had the wrong JSON type.
Unknown
Unknown variant for forward compatibility.