pub enum CatalogTrustTier {
T1,
T2,
Unknown,
}Expand description
Service-computed trust tier currently emitted by Agent Finder. It is independent of search score, popularity, and client-side ranking.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
T1
Tier one as assigned by the catalogue authority.
T2
Tier two as assigned by the catalogue authority.
Unknown
Unknown variant for forward compatibility.