pub enum CatalogUnavailableReason {
SearchUnavailable,
PlanningUnavailable,
AuthorityNotConfigured,
DisabledByPolicy,
Unknown,
}Expand description
Why a catalog operation is not available on this runtime
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Bounded search is not wired up on this runtime build.
Install planning is not wired up on this runtime build.
AuthorityNotConfigured
No catalog authority is configured for this runtime.
DisabledByPolicy
The surface is disabled by policy on this runtime.
Unknown
Unknown variant for forward compatibility.