pub enum EnqueueCommandResult {
AcceptedEnqueueCommandResult(AcceptedEnqueueCommandResult),
UnsupportedEnqueueCommandResult(UnsupportedEnqueueCommandResult),
}Expand description
Indicates whether the command was accepted into the local execution queue.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
AcceptedEnqueueCommandResult(AcceptedEnqueueCommandResult)
UnsupportedEnqueueCommandResult(UnsupportedEnqueueCommandResult)