pub enum SessionLimitPredictionSource {
Model,
Family,
Global,
Unknown,
}Expand description
Baseline fallback level used to create the prediction.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Model
The prediction used the exact resolved model’s baseline cell.
Family
The exact model was unavailable, so the prediction used the model family’s baseline cell.
Global
No model or family cell was available, so the prediction used the global client-type baseline cell.
Unknown
Unknown variant for forward compatibility.