pub enum SkillInstallationManagementOutcome {
RecoveryRequired(SkillInstallationManagementOutcomeRecoveryRequired),
InstallPlanned(SkillInstallationManagementOutcomeInstallPlanned),
Listed(SkillInstallationManagementOutcomeListed),
Recovered(SkillInstallationManagementOutcomeRecovered),
RolledBack(SkillInstallationManagementOutcomeRolledBack),
UninstallPlanned(SkillInstallationManagementOutcomeUninstallPlanned),
Operation(SkillInstallationManagementOutcomeOperation),
EnabledChanged(SkillInstallationManagementOutcomeEnabledChanged),
Refused(SkillInstallationManagementOutcomeRefused),
}Expand description
Management outcome for verified Skill inventory, planning and removal.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
RecoveryRequired(SkillInstallationManagementOutcomeRecoveryRequired)
InstallPlanned(SkillInstallationManagementOutcomeInstallPlanned)
Listed(SkillInstallationManagementOutcomeListed)
Recovered(SkillInstallationManagementOutcomeRecovered)
RolledBack(SkillInstallationManagementOutcomeRolledBack)
UninstallPlanned(SkillInstallationManagementOutcomeUninstallPlanned)
Operation(SkillInstallationManagementOutcomeOperation)
EnabledChanged(SkillInstallationManagementOutcomeEnabledChanged)
Refused(SkillInstallationManagementOutcomeRefused)