pub enum SkillInstallationManagementResult {
Outcome(SkillInstallationManagementResultOutcome),
NegotiationRefused(CatalogNegotiationRefusedError),
InvalidRequest(CatalogInvalidRequestError),
}Expand description
Skill installation management result with the honoured contract, or a typed refusal.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Outcome(SkillInstallationManagementResultOutcome)
NegotiationRefused(CatalogNegotiationRefusedError)
InvalidRequest(CatalogInvalidRequestError)