pub enum SkillInstallationResult {
Outcome(SkillInstallationResultOutcome),
NegotiationRefused(CatalogNegotiationRefusedError),
InvalidRequest(CatalogInvalidRequestError),
}Expand description
Skill installation result with the honoured contract, or a typed request/negotiation refusal.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Outcome(SkillInstallationResultOutcome)
NegotiationRefused(CatalogNegotiationRefusedError)
InvalidRequest(CatalogInvalidRequestError)