pub enum SlashCommandInvocationResult {
Text(SlashCommandTextResult),
AgentPrompt(SlashCommandAgentPromptResult),
Completed(SlashCommandCompletedResult),
SelectSubcommand(SlashCommandSelectSubcommandResult),
}Expand description
Result of invoking the slash command (text output, prompt to send to the agent, or completion).
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Text(SlashCommandTextResult)
AgentPrompt(SlashCommandAgentPromptResult)
Completed(SlashCommandCompletedResult)
SelectSubcommand(SlashCommandSelectSubcommandResult)