pub struct AccountAllUsers {
pub auth_info: AuthInfo,
pub selection_id: Option<String>,
pub token: Option<String>,
}Expand description
Authenticated account entry returned by account.getAllUsers.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
auth_info: AuthInfoAuthentication information for this user
selection_id: Option<String>Opaque identifier accepted by account and model selection APIs
token: Option<String>Associated token, if available