pub struct AgentsGetDiscoveryPathsResult {
pub paths: Vec<AgentDiscoveryPath>,
}Expand description
Canonical locations where custom agents can be created so the runtime will recognize them.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
paths: Vec<AgentDiscoveryPath>Canonical agent create/discovery directories, in priority order