pub struct AttachmentFileLineRange {
pub end: i64,
pub start: i64,
}Expand description
Optional line range to scope the attachment to a specific section of the file
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
end: i64End line number (1-based, inclusive)
start: i64Start line number (1-based)