pub struct CanvasAction {
pub description: Option<String>,
pub input_schema: Option<Value>,
pub name: String,
}Expand description
Canvas action that the agent or host can invoke. To discover the input schema for a particular action, call the list_canvas_capabilities tool.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
description: Option<String>Description of the action
input_schema: Option<Value>JSON Schema for the action input
name: StringAction name exposed by the canvas provider