pub struct CatalogTrustSnapshotMalformed {
pub eligibility: CatalogTrustEligibility,
pub provenance: CatalogTrustProvenance,
pub schema_version: CatalogTrustSnapshotSchemaVersion,
pub status: CatalogTrustSnapshotMalformedStatus,
}Expand description
Discriminator: the trust field was empty, unbounded, or had the wrong JSON type.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
eligibility: CatalogTrustEligibilityService-computed exposure eligibility. unknown is required while Agent Finder returns no explicit eligibility field.
provenance: CatalogTrustProvenanceBounded source and observation time for this snapshot. This is distinct from evidence used by the authority to calculate trust.
schema_version: CatalogTrustSnapshotSchemaVersionSchema version of this runtime-owned snapshot envelope.
status: CatalogTrustSnapshotMalformedStatusDiscriminator: the trust field was empty, unbounded, or had the wrong JSON type.