pub struct CatalogTrustSnapshotRevoked {
pub eligibility: CatalogTrustEligibility,
pub provenance: CatalogTrustProvenance,
pub schema_version: CatalogTrustSnapshotSchemaVersion,
pub status: CatalogTrustSnapshotRevokedStatus,
}Expand description
Discriminator: the authority explicitly revoked the assessment.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
eligibility: CatalogTrustEligibilityService-computed exposure eligibility. unknown is required while Agent Finder returns no explicit eligibility field.
provenance: CatalogTrustProvenanceBounded source and observation time for this snapshot. This is distinct from evidence used by the authority to calculate trust.
schema_version: CatalogTrustSnapshotSchemaVersionSchema version of this runtime-owned snapshot envelope.
status: CatalogTrustSnapshotRevokedStatusDiscriminator: the authority explicitly revoked the assessment.