ClientRpcMcpConfig

Struct ClientRpcMcpConfig 

pub struct ClientRpcMcpConfig<'a> { /* private fields */ }
mcp.config.* RPCs.

Implementations

Source

impl<'a> ClientRpcMcpConfig<'a>

pub async fn list(&self) -> Result<McpConfigList, Error>

Lists MCP servers from user configuration.

Wire method: mcp.config.list.

Returns

User-configured MCP servers, keyed by server name.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn add(&self, params: McpConfigAddRequest) -> Result<(), Error>

Adds an MCP server to user configuration.

Wire method: mcp.config.add.

Parameters
  • params - MCP server name and configuration to add to user configuration.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn update(&self, params: McpConfigUpdateRequest) -> Result<(), Error>

Updates an MCP server in user configuration.

Wire method: mcp.config.update.

Parameters
  • params - MCP server name and replacement configuration to write to user configuration.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn remove(&self, params: McpConfigRemoveRequest) -> Result<(), Error>

Removes an MCP server from user configuration.

Wire method: mcp.config.remove.

Parameters
  • params - MCP server name to remove from user configuration.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn enable(&self, params: McpConfigEnableRequest) -> Result<(), Error>

Enables MCP servers in user configuration for new sessions.

Wire method: mcp.config.enable.

Parameters
  • params - MCP server names to enable for new sessions.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn disable( &self, params: McpConfigDisableRequest, ) -> Result<(), Error>

Disables MCP servers in user configuration for new sessions.

Wire method: mcp.config.disable.

Parameters
  • params - MCP server names to disable for new sessions.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn reload(&self) -> Result<(), Error>

Drops this runtime process’s in-memory MCP server-definition cache so the next MCP config read observes disk.

Wire method: mcp.config.reload.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.