ClientRpcModels

Struct ClientRpcModels 

pub struct ClientRpcModels<'a> { /* private fields */ }
models.* RPCs.

Implementations

Source

impl<'a> ClientRpcModels<'a>

pub async fn list(&self) -> Result<ModelList, Error>

Lists Copilot models available to the authenticated user.

Wire method: models.list.

Returns

List of Copilot models available to the resolved user, including capabilities and billing metadata.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn list_with_params( &self, params: ModelsListRequest, ) -> Result<ModelList, Error>

Lists Copilot models available to the authenticated user.

Wire method: models.list.

Parameters
  • params - Optional GitHub token used to list models for a specific user instead of the global auth context.
Returns

List of Copilot models available to the resolved user, including capabilities and billing metadata.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.