pub struct ClientRpcSessionFs<'a> { /* private fields */ }Expand description
sessionFs.* RPCs.
Implementations
Sourceimpl<'a> ClientRpcSessionFs<'a>
impl<'a> ClientRpcSessionFs<'a>
Sourcepub async fn set_provider(
&self,
params: SessionFsSetProviderRequest,
) -> Result<SessionFsSetProviderResult, Error>
pub async fn set_provider( &self, params: SessionFsSetProviderRequest, ) -> Result<SessionFsSetProviderResult, Error>
Registers an SDK client as the session filesystem provider.
Wire method: sessionFs.setProvider.
Parameters
params- Initial working directory, session-state path layout, and path conventions used to register the calling SDK client as the session filesystem provider.
Returns
Indicates whether the calling client was registered as the session filesystem provider.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.