pub struct CommandsHandlePendingCommandRequest {
pub error: Option<String>,
pub request_id: RequestId,
}Expand description
Pending command request ID and an optional error if the client handler failed.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
error: Option<String>Error message if the command handler failed
request_id: RequestIdRequest ID from the command invocation event