pub struct CommandsListResult {
pub commands: Vec<SlashCommandInfo>,
}Expand description
Slash commands available in the session, after applying any include/exclude filters.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
commands: Vec<SlashCommandInfo>Commands available in this session