pub struct CommandsRespondToQueuedCommandRequest {
pub request_id: RequestId,
pub result: Value,
}Expand description
Queued-command request ID and the result indicating whether the host executed it (and whether to stop processing further queued commands).
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
request_id: RequestIdRequest ID from the command.queued event the host is responding to.
result: ValueResult of the queued command execution.