pub struct ConnectorConnectResultPending {
pub continuation_id: String,
pub kind: ConnectorConnectResultPendingKind,
}Expand description
The service is still completing the connection without a consent URL.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
continuation_id: StringOpaque ID accepted by continueConnection.
kind: ConnectorConnectResultPendingKindThe service is still completing the connection without a consent URL.