pub struct CopilotUserResponseQuotaSnapshots {
pub chat: Option<CopilotUserResponseQuotaSnapshotsChat>,
pub completions: Option<CopilotUserResponseQuotaSnapshotsCompletions>,
pub premium_interactions: Option<CopilotUserResponseQuotaSnapshotsPremiumInteractions>,
}Expand description
Quota snapshot map from the raw Copilot user-response passthrough, with chat, completions, premium-interactions, and other entries.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
chat: Option<CopilotUserResponseQuotaSnapshotsChat>Chat quota snapshot from the raw Copilot user-response passthrough, with entitlement, overage, remaining quota, reset, and billing fields.
completions: Option<CopilotUserResponseQuotaSnapshotsCompletions>Completions quota snapshot from the raw Copilot user-response passthrough, with entitlement, overage, remaining quota, reset, and billing fields.
Premium-interactions quota snapshot from the raw Copilot user-response passthrough, with entitlement, overage, remaining quota, reset, and billing fields.