pub struct DebugCollectLogsCollectedEntry {
pub bundle_path: String,
pub size_bytes: i64,
pub source: DebugCollectLogsSource,
}Expand description
A file included in the session debug bundle.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
bundle_path: StringRelative path of the file in the staged bundle/archive.
size_bytes: i64Redacted output size in bytes.
source: DebugCollectLogsSourceSource category for this entry.