pub struct DebugCollectLogsSkippedEntry {
pub bundle_path: String,
pub path: Option<String>,
pub reason: String,
}Expand description
An optional debug bundle entry that could not be included.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
bundle_path: StringRelative path requested for this bundle entry.
path: Option<String>Server-local source path that could not be read.
reason: StringReason the entry was skipped.