pub struct DiagnosticSourcesConfiguration {
pub mcp: Option<McpDiagnosticSourceConfiguration>,
}Expand description
Typed diagnostic source configuration. At least one source is required by diagnostics configuration methods.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
mcp: Option<McpDiagnosticSourceConfiguration>MCP diagnostic capture threshold. Omit to leave the current threshold unchanged.