pub struct DiscoveredExtensionsEnableRequest {
pub ids: Vec<String>,
}Expand description
Source-qualified extension identifiers to persistently enable for future sessions.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
ids: Vec<String>Source-qualified user or plugin extension IDs to enable