pub struct DiscoveredMcpServer {
pub enabled: bool,
pub name: String,
pub source: McpServerSource,
pub source_plugin: Option<String>,
pub source_plugin_version: Option<String>,
pub type: Option<DiscoveredMcpServerType>,
}Expand description
Schema for the DiscoveredMcpServer type.
Fields
enabled: boolWhether the server is enabled (not in the disabled list)
name: StringServer name (config key)
source: McpServerSourceConfiguration source: user, workspace, plugin, or builtin
source_plugin: Option<String>Plugin name that provided this server, when source is plugin.
source_plugin_version: Option<String>Plugin version that provided this server, when source is plugin.
type: Option<DiscoveredMcpServerType>Server transport type: stdio, http, sse (deprecated), or memory