pub struct FactoryExecuteRequest {
pub session_id: SessionId,
pub name: String,
pub run_id: String,
pub args: Value,
}Expand description
Parameters sent to the owning extension to execute a factory closure.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
session_id: SessionIdTarget session identifier
name: StringRegistered factory name.
run_id: StringFactory run identifier.
args: ValueFactory input value.