pub struct HistoryTruncateResult {
pub events_removed: i64,
}Expand description
Number of events that were removed by the truncation.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
events_removed: i64Number of events that were removed