pub struct InstructionDiscoveryPathList {
pub paths: Vec<InstructionDiscoveryPath>,
}Expand description
Canonical files and directories where custom instructions can be created so the runtime will recognize them.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
paths: Vec<InstructionDiscoveryPath>Canonical instruction create/discovery files and directories, in priority order