pub struct McpPlanTarget {
pub config_key: String,
pub scope: McpPlanScope,
}Expand description
Where a plan would be written.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
config_key: StringConfiguration key the server would be recorded under within that scope.
scope: McpPlanScopeConfiguration scope the plan targets.