pub struct McpRemoveGitHubResult {
pub removed: bool,
}Expand description
Indicates whether the auto-managed github MCP server was removed (false when nothing to remove).
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
removed: boolTrue when the auto-managed github MCP server was removed; false when no removal happened (e.g. user has explicitly configured a github server, or the server was not registered).