pub struct McpSafeForTelemetryFields {
pub inputs_names: bool,
pub name: bool,
}Expand description
Per-field MCP telemetry-obfuscation policy.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
inputs_names: boolWhether MCP tool input names may be included in telemetry without obfuscation.
name: boolWhether the MCP tool name may be included in telemetry without obfuscation.