pub struct ModeSetRequest {
pub compaction_decision: Option<String>,
pub inherit_plan_base_from_session_id: Option<String>,
pub mode: SessionMode,
pub persist_plan_selection: Option<bool>,
pub picker_settings_context: Option<ModelPickerSettingsContext>,
pub plan_context_tier: Option<String>,
pub plan_exit_action: Option<String>,
pub plan_model: Option<String>,
pub plan_model_configured: Option<bool>,
pub plan_reasoning_effort: Option<String>,
pub restore_plan_model: Option<bool>,
}Expand description
Agent interaction mode to apply to the session.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
compaction_decision: Option<String>Explicit response to a model-switch compaction preflight.
inherit_plan_base_from_session_id: Option<String>Session whose plan-mode base state should be inherited.
mode: SessionModeThe session mode the agent is operating in
persist_plan_selection: Option<bool>Whether the selected plan model should be persisted.
picker_settings_context: Option<ModelPickerSettingsContext>Settings context used when persisting the selected plan model.
plan_context_tier: Option<String>Context tier to use with the dedicated plan model.
plan_exit_action: Option<String>Action to perform when leaving plan mode.
plan_model: Option<String>Dedicated model to use in plan mode, when configured.
plan_model_configured: Option<bool>Whether a dedicated plan model is configured.
plan_reasoning_effort: Option<String>Reasoning effort to use with the dedicated plan model.
restore_plan_model: Option<bool>Whether leaving plan mode should restore the session’s previous model.