pub struct ModelBillingTokenPricesLongContext {
pub cache_price: Option<f64>,
pub cache_read_price: Option<f64>,
pub cache_write_price: Option<f64>,
pub context_max: Option<i64>,
pub input_price: Option<f64>,
pub max_prompt_tokens: Option<i64>,
pub output_price: Option<f64>,
}Expand description
Long context tier pricing (available for models with extended context windows)
Fields
cache_price: Option<f64>Deprecated: use cacheReadPrice. AI Credits cost per billing batch of cached tokens
cache_read_price: Option<f64>AI Credits cost per billing batch of cached (read) tokens
cache_write_price: Option<f64>AI Credits cost per billing batch of cache-write (cache creation) tokens.
context_max: Option<i64>Deprecated: use maxPromptTokens. Prompt token budget for the long context tier. The total context window is this value plus the model’s max_output_tokens.
input_price: Option<f64>AI Credits cost per billing batch of input tokens
max_prompt_tokens: Option<i64>Prompt token budget for the long context tier. The total context window is this value plus the model’s max_output_tokens.
output_price: Option<f64>AI Credits cost per billing batch of output tokens