pub struct PermissionDecisionApprovedForSession {
pub approval: UserToolSessionApproval,
pub kind: PermissionDecisionApprovedForSessionKind,
}Expand description
Schema for the PermissionDecisionApprovedForSession type.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
approval: UserToolSessionApprovalThe approval to add as a session-scoped rule
kind: PermissionDecisionApprovedForSessionKindApproved and remembered for the rest of the session