pub struct PermissionLocationApplyParams {
pub working_directory: String,
}Expand description
Working directory to load persisted location permissions for.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
working_directory: StringWorking directory whose persisted location permissions should be applied