pub struct PermissionLocationResolveResult {
pub location_key: String,
pub location_type: PermissionLocationType,
}Expand description
Resolved location-permissions key and type.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
location_key: StringLocation key used in the location-permissions store
location_type: PermissionLocationTypeWhether the location is a git repo or directory