pub struct PermissionPathsUpdatePrimaryParams {
pub path: String,
}Expand description
Directory path to set as the session’s new primary working directory.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
path: StringDirectory to set as the new primary working directory for the session’s permission policy.