pub struct PlanReadResult {
pub content: Option<String>,
pub exists: bool,
pub path: Option<String>,
}Expand description
Existence, contents, and resolved path of the session plan file.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
content: Option<String>The content of the plan file, or null if it does not exist
exists: boolWhether the plan file exists in the workspace
path: Option<String>Absolute file path of the plan file, or null if workspace is not enabled