pub struct ProtocolStaticSectionOverride {
pub action: ProtocolStaticSectionAction,
pub content: Option<String>,
}Expand description
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
action: ProtocolStaticSectionActionDeclarative operation applied to the section.
content: Option<String>Optional content used by replace, append, and prepend operations.