pub struct ScheduleList {
pub entries: Vec<ScheduleEntry>,
}Expand description
Snapshot of the currently active recurring prompts for this session.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
entries: Vec<ScheduleEntry>Active scheduled prompts, ordered by id.