pub struct SessionFactoryListRunsResult {
pub has_more_newer: Option<bool>,
pub newest_seq: Option<i64>,
pub oldest_seq: Option<i64>,
pub omitted_older: Option<i64>,
pub runs: Vec<FactoryRunSummary>,
}Expand description
A page of factory runs in durable creation order.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
has_more_newer: Option<bool>Whether terminal runs newer than this page exist.
newest_seq: Option<i64>Newest terminal-run cursor in this page, or null when the terminal window is empty.
oldest_seq: Option<i64>Oldest terminal-run cursor in this page, or null when the terminal window is empty.
omitted_older: Option<i64>Number of terminal runs older than this page.
runs: Vec<FactoryRunSummary>Trait Implementations
Sourceimpl Clone for SessionFactoryListRunsResult
impl Clone for SessionFactoryListRunsResult
Sourcefn clone(&self) -> SessionFactoryListRunsResult
fn clone(&self) -> SessionFactoryListRunsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionFactoryListRunsResult
impl Debug for SessionFactoryListRunsResult
Sourceimpl Default for SessionFactoryListRunsResult
impl Default for SessionFactoryListRunsResult
Sourcefn default() -> SessionFactoryListRunsResult
fn default() -> SessionFactoryListRunsResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionFactoryListRunsResult
impl<'de> Deserialize<'de> for SessionFactoryListRunsResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more