pub struct SessionFactoryRunResult {
pub error: Option<String>,
pub failure: Option<Value>,
pub reason: Option<String>,
pub result: Option<Value>,
pub run_id: String,
pub snapshot: Option<Value>,
pub status: FactoryRunStatus,
}Expand description
Complete current or terminal factory run envelope.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
error: Option<String>Error message for an errored run.
failure: Option<Value>Machine-readable failure details for an errored run.
reason: Option<String>Reason for a halted or cancelled run.
result: Option<Value>Completed factory result.
run_id: StringFactory run identifier.
snapshot: Option<Value>Partial journal and progress snapshot for a halted, cancelled, or errored run.
status: FactoryRunStatusCurrent or terminal factory run status.