pub struct SessionHistoryTruncateResult {
pub checkpoint_cleanup_error: Option<String>,
pub checkpoint_cleanup_failed: Option<bool>,
pub events_removed: i64,
}Expand description
Number of events that were removed by the truncation.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
checkpoint_cleanup_error: Option<String>Failure detail when checkpointCleanupFailed is true.
checkpoint_cleanup_failed: Option<bool>True when conversation truncation succeeded but post-truncation workspace checkpoint cleanup failed. History is already truncated; callers may still prune snapshots but should report a checkpoint-cleanup rather than a truncation failure.
events_removed: i64Number of events that were removed