pub struct SessionLogResult {
pub event_id: String,
}Expand description
Identifier of the session event that was emitted for the log message.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
event_id: StringThe unique identifier of the emitted session event