pub struct SessionMcpCancelSamplingExecutionResult {
pub cancelled: bool,
}Expand description
Indicates whether an in-flight sampling execution with the given requestId was found and cancelled.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
cancelled: boolTrue if an in-flight execution with the given requestId was found and signalled to cancel. False when no such execution is in flight (already completed, never started, or cancelled by another caller).