pub struct SessionMcpResourcesListResult {
pub next_cursor: Option<String>,
pub resources: Vec<McpResource>,
}Expand description
One page of resources advertised by the named MCP server.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
next_cursor: Option<String>Opaque cursor for the next page, if the server has more resources
resources: Vec<McpResource>Resources advertised by the server (proxied MCP resources/list)