pub struct SessionMcpSetEnvValueModeResult {
pub mode: McpSetEnvValueModeDetails,
}Expand description
Env-value mode recorded on the session after the update.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
mode: McpSetEnvValueModeDetailsMode recorded on the session after the update