pub struct SessionPermissionsPathsIsPathWithinAllowedDirectoriesResult {
pub allowed: bool,
}Expand description
Indicates whether the supplied path is within the session’s allowed directories.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
allowed: boolWhether the path is within the session’s allowed directories