SessionRpcFactoryJournal

Struct SessionRpcFactoryJournal 

pub struct SessionRpcFactoryJournal<'a> { /* private fields */ }
session.factory.journal.* RPCs.

Implementations

Source

impl<'a> SessionRpcFactoryJournal<'a>

pub async fn get( &self, params: FactoryJournalGetRequest, ) -> Result<FactoryJournalGetResult, Error>

Reads a memoized factory journal entry.

Wire method: session.factory.journal.get.

Parameters
  • params - Parameters for reading a factory journal entry.
Returns

Result of reading a factory journal entry.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.

pub async fn put( &self, params: FactoryJournalPutRequest, ) -> Result<FactoryAckResult, Error>

Stores a memoized factory journal entry.

Wire method: session.factory.journal.put.

Parameters
  • params - Parameters for storing a factory journal entry.
Returns

Acknowledgement that a factory request was accepted.

Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.