pub struct SessionRpcMcpHeaders<'a> { /* private fields */ }Expand description
session.mcp.headers.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcMcpHeaders<'a>
impl<'a> SessionRpcMcpHeaders<'a>
Sourcepub async fn handle_pending_headers_refresh_request(
&self,
params: McpHeadersHandlePendingHeadersRefreshRequestRequest,
) -> Result<McpHeadersHandlePendingHeadersRefreshRequestResult, Error>
pub async fn handle_pending_headers_refresh_request( &self, params: McpHeadersHandlePendingHeadersRefreshRequestRequest, ) -> Result<McpHeadersHandlePendingHeadersRefreshRequestResult, Error>
Responds to a pending MCP dynamic headers refresh request. Hosts that subscribe to mcp.headers_refresh_required use this to provide short-lived per-server headers or to indicate that no dynamic headers are available for this refresh.
Wire method: session.mcp.headers.handlePendingHeadersRefreshRequest.
Parameters
params- MCP headers refresh request id and the host response.
Returns
Indicates whether the pending MCP headers refresh response was accepted.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.