pub struct SessionSkillsGetInvokedResult {
pub skills: Vec<SkillsInvokedSkill>,
}Expand description
Skills invoked during this session, ordered by invocation time (most recent last).
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
skills: Vec<SkillsInvokedSkill>Skills invoked during this session, ordered by invocation time (most recent last)