pub struct SessionUiHandlePendingUserInputResult {
pub success: bool,
}Expand description
Indicates whether the pending UI request was resolved by this call.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
success: boolTrue if the request was still pending and was resolved by this call. False if the request ID was unknown, already resolved by another client (e.g. GitHub), expired, or otherwise no longer pending.