pub struct SessionWorkflowPauseAtCheckpointResult {
pub action: WorkflowPauseCheckpointAction,
}Expand description
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
action: WorkflowPauseCheckpointActionWhether this execution attempt must pause or may continue.