pub struct SessionWorkspacesGetWorkspaceResultWorkspace {Show 17 fields
pub branch: Option<String>,
pub chronicle_sync_dismissed: Option<bool>,
pub client_name: Option<String>,
pub created_at: Option<String>,
pub cwd: Option<String>,
pub git_root: Option<String>,
pub host_type: Option<WorkspacesWorkspaceDetailsHostType>,
pub id: String,
pub mc_last_event_id: Option<String>,
pub mc_session_id: Option<String>,
pub mc_task_id: Option<String>,
pub name: Option<String>,
pub remote_steerable: Option<bool>,
pub repository: Option<String>,
pub summary_count: Option<i64>,
pub updated_at: Option<String>,
pub user_named: Option<bool>,
}Fields
branch: Option<String>Current Git branch.
chronicle_sync_dismissed: Option<bool>Whether the per-session Chronicle upgrade prompt was dismissed for the workspace.
client_name: Option<String>Name of the client that created the workspace.
created_at: Option<String>Timestamp when the workspace was created.
cwd: Option<String>Current working directory associated with the workspace.
git_root: Option<String>Git repository root associated with the workspace.
host_type: Option<WorkspacesWorkspaceDetailsHostType>Allowed values for the WorkspacesWorkspaceDetailsHostType enumeration.
id: StringStable workspace identifier.
mc_last_event_id: Option<String>Most recent Mission Control event identifier observed for the workspace.
mc_session_id: Option<String>Mission Control session identifier associated with the workspace.
mc_task_id: Option<String>Mission Control task identifier associated with the workspace.
name: Option<String>Workspace display name.
remote_steerable: Option<bool>Whether the workspace session can be steered remotely.
repository: Option<String>Repository identifier associated with the workspace.
summary_count: Option<i64>Number of persisted summaries in the workspace.
updated_at: Option<String>Timestamp when the workspace was last updated.
user_named: Option<bool>Whether the workspace name was explicitly chosen by the user.