pub struct SessionWorkspacesListFilesResult {
pub files: Vec<String>,
}Expand description
Relative paths of files stored in the session workspace files directory.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
files: Vec<String>Slash-separated relative file paths in the workspace files directory