pub struct TasksPromoteToBackgroundRequest {
pub id: String,
}Expand description
Identifier of the task to promote to background mode.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
id: StringTask identifier