pub struct ToolsListResult {
pub tools: Vec<Tool>,
}Expand description
Built-in tools available for the requested model, with their parameters and instructions.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
tools: Vec<Tool>List of available built-in tools with metadata