pub struct ToolsShellDescriptorConfig {
pub description_lines: Vec<String>,
pub display_name: String,
pub list_shells_tool_name: String,
pub read_shell_tool_name: String,
pub shell_tool_name: String,
pub shell_type: String,
pub stop_shell_tool_name: String,
}Expand description
Shell-specific names and description lines used to materialize built-in shell tool descriptors.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
description_lines: Vec<String>Additional model-facing shell description lines.
display_name: StringHuman-readable shell name.
list_shells_tool_name: StringTool name used to list active shells.
read_shell_tool_name: StringTool name used to read shell output.
shell_tool_name: StringTool name used to start shell commands.
shell_type: StringStable shell type identifier.
stop_shell_tool_name: StringTool name used to stop shell commands.