pub struct UIElicitationArrayAnyOfFieldItems {
pub any_of: Vec<UIElicitationArrayAnyOfFieldItemsAnyOf>,
}Expand description
Schema applied to each item in the array.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
any_of: Vec<UIElicitationArrayAnyOfFieldItemsAnyOf>Selectable options, each with a value and a display label.