pub struct UIHandlePendingSamplingRequest {
pub request_id: RequestId,
pub response: Option<UIHandlePendingSamplingResponse>,
}Expand description
Request ID of a pending sampling.requested event and an optional sampling result payload (omit to reject).
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
request_id: RequestIdThe unique request ID from the sampling.requested event
response: Option<UIHandlePendingSamplingResponse>Optional sampling result payload. Omit to reject/cancel the sampling request without providing a result.