pub struct WorkflowExecuteRequest {
pub session_id: SessionId,
pub name: String,
pub run_id: String,
pub execution_token: String,
pub args: Value,
}Expand description
Parameters sent to the owning extension to execute a workflow closure.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
session_id: SessionIdTarget session identifier
name: StringRegistered workflow name.
run_id: StringWorkflow run identifier.
execution_token: StringOpaque token identifying this workflow execution attempt.
args: ValueWorkflow input value.