pub struct WorkspacesCreateFileRequest {
pub content: String,
pub path: String,
}Expand description
Relative path and UTF-8 content for the workspace file to create or overwrite.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
content: StringFile content to write as a UTF-8 string
path: StringSlash-separated relative path within the workspace files directory