pub struct WorkspacesSaveLargePasteResult {
pub saved: Option<WorkspacesSaveLargePasteResultSaved>,
}Expand description
Descriptor for the saved paste file, or null when the workspace is unavailable.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
saved: Option<WorkspacesSaveLargePasteResultSaved>Saved-paste descriptor, or null when the workspace is unavailable (e.g. CCA runtime, non-infinite sessions, remote sessions)