Module session

Module session 

Session management — create, resume, send messages, and interact with the agent.

Structs

PreparedSession
A session that has been configured but not yet created on the CLI.
Session
A session on a GitHub Copilot CLI server.
SessionUi
UI sub-API for a Session — elicitation, confirmation, selection, and free-form input.

Constants

DEFAULT_EVENT_BUFFER_CAPACITY
Default capacity of the per-session event broadcast buffer backing Session::subscribe and PreparedSession::subscribe.