pub enum AutoTierSwitchFailureReason {
PolicyRejected,
RequestFailed,
SetupFailed,
Unsupported,
Unknown,
}Expand description
Terminal reason an Auto preference activation failed.
Variants
PolicyRejected
The candidate model was rejected by model policy.
RequestFailed
The Auto routing request failed or returned an unusable response.
SetupFailed
The runtime could not prepare the Auto routing request.
Unsupported
The provider does not support Auto routing.
Unknown
Unknown variant for forward compatibility.