pub enum McpOauthRequestReason {
Initial,
Refresh,
Reauth,
Upscope,
Unknown,
}Expand description
Reason the runtime is requesting host-provided MCP OAuth credentials
Variants
Initial
Initial credentials are required before connecting to the MCP server.
Refresh
The current host-provided credential was rejected and a replacement is requested.
Reauth
The server requires a new host authorization flow before continuing.
Upscope
The server requires a credential with additional scope or audience.
Unknown
Unknown variant for forward compatibility.