pub enum ModelCallFinishedOutcome {
Success,
Error,
Cancelled,
Rejected,
Unknown,
}Expand description
Final outcome of one logical model dispatch after response acceptance processing
Variants
Success
The provider response was accepted for continued agent processing.
Error
The dispatch ended with a provider or transport error.
Cancelled
The dispatch was cancelled before an accepted response was produced.
Rejected
The provider response was rejected during post-response acceptance processing.
Unknown
Unknown variant for forward compatibility.