pub enum PermissionRecoveryAttemptReason {
PermissionRequired,
RepeatedAttempt,
AttemptsExhausted,
PermissionApproved,
PermissionDenied,
ResponderUnavailable,
EquivalentAlternativeSucceeded,
Unknown,
}Expand description
Controlled reason for an individual attempt disposition
Variants
PermissionRequired
The attempt required permission that Assisted Permissions could not grant.
RepeatedAttempt
The request repeated an earlier attempt.
AttemptsExhausted
The request exceeded the bounded number of distinct attempts.
PermissionApproved
The interactive responder approved the request.
PermissionDenied
The interactive responder denied the request.
The interactive responder became unavailable.
EquivalentAlternativeSucceeded
The tool call succeeded without the blocked permission.
Unknown
Unknown variant for forward compatibility.