pub enum SubagentModelSelectionSource {
ExplicitOverride,
ConfiguredRequired,
ConfiguredPreference,
ComplementaryDefault,
SessionInheritance,
AgentDefinitionDefault,
RuntimePolicy,
Unknown,
}Expand description
Authority or runtime mechanism responsible for sub-agent model selection.
Variants
ExplicitOverride
Explicit model supplied by the parent agent on the task call and selected for dispatch.
ConfiguredRequired
Required model policy configured for the sub-agent.
ConfiguredPreference
Non-required model preference configured for the sub-agent.
ComplementaryDefault
Complementary-model default selected for the sub-agent.
SessionInheritance
Model inherited from the parent session.
AgentDefinitionDefault
Default model declared by the agent definition.
RuntimePolicy
Runtime policy, Auto mode, or an experiment selected the model.
Unknown
Unknown variant for forward compatibility.