pub struct AssistantTurnRetryData {
pub model: Option<String>,
pub reason: Option<String>,
pub turn_id: String,
}Expand description
Session event “assistant.turn_retry”. Metadata for an additional model inference attempt within an existing assistant turn
Fields
model: Option<String>Model identifier used for this retry, when known
reason: Option<String>Provider or runtime classification that caused the retry, when known
turn_id: StringIdentifier of the turn whose model inference is being retried