pub struct FusionCritic {
pub model: String,
pub phase_id: String,
pub reasoning_effort: Option<String>,
}Expand description
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
model: StringConcrete model selected for this critic.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
phase_id: StringUnique execution phase identifier for this critic.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
reasoning_effort: Option<String>Explicit reasoning effort selected for this critic, if supplied.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.