pub struct SandboxDecisionData {}Expand description
Session event “sandbox.decision”. Payload of sandbox.decision, a bounded governance record of what the process sandbox was configured to do and whether it took effect. Discriminated by kind.