pub struct SessionAutopilotObjectiveChangedData {
pub id: Option<i64>,
pub operation: AutopilotObjectiveChangedOperation,
pub status: Option<AutopilotObjectiveChangedStatus>,
}Expand description
Session event “session.autopilot_objective_changed”. Autopilot objective state file operation details indicating what changed
Fields
id: Option<i64>Current autopilot objective id, if one exists
operation: AutopilotObjectiveChangedOperationThe type of operation performed on the autopilot objective state file
status: Option<AutopilotObjectiveChangedStatus>Current autopilot objective status, if one exists