pub struct SessionFusionResolvedData {Show 21 fields
pub contract_version: i64,
pub fallback_model: String,
pub follow_up: Option<FusionFollowUpRecommendation>,
pub follow_up_model: String,
pub fusion_id: String,
pub model_universe_version: Option<String>,
pub pattern: FusionPattern,
pub phase_plan: Option<Vec<FusionPhasePlanStep>>,
pub plan_version: Option<String>,
pub policy: String,
pub policy_version: Option<String>,
pub primary_model: String,
pub route_source: Option<String>,
pub routing_latency_ms: Option<f64>,
pub rule_id: Option<String>,
pub rule_index: Option<i64>,
pub rule_name: Option<String>,
pub scores: Option<FusionScores>,
pub secondary_model: Option<String>,
pub synthetic_model: String,
pub turn_id: String,
}Expand description
Session event “session.fusion_resolved”. Experimental durable validated HydraFusion route and turn policy.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
contract_version: i64Version of the validated HydraFusion event contract.
fallback_model: StringConcrete model used when the planned primary model cannot execute.
follow_up: Option<FusionFollowUpRecommendation>Router recommendation controlling reuse or rerouting on later turns.
follow_up_model: StringConcrete model recommended for eligible follow-up turns.
fusion_id: StringStable identifier for the resolved HydraFusion turn.
model_universe_version: Option<String>Version of the executable model universe used for selection.
pattern: FusionPatternValidated orchestration pattern selected for the turn.
phase_plan: Option<Vec<FusionPhasePlanStep>>Presentation-neutral phase plan for clients that render workflow progress.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
plan_version: Option<String>Version of the validated execution-plan format.
policy: StringHydraFusion routing policy used to resolve the plan.
policy_version: Option<String>Version of the local routing policy.
primary_model: StringConcrete model selected for the primary solver phase.
route_source: Option<String>Router implementation that supplied the plan.
routing_latency_ms: Option<f64>Elapsed time in milliseconds required to resolve and validate the route.
rule_id: Option<String>Identifier of the local policy rule that matched.
rule_index: Option<i64>Zero-based index of the local policy rule that matched.
rule_name: Option<String>Human-readable name of the local policy rule that matched.
scores: Option<FusionScores>Validated capability scores used to select the route.
secondary_model: Option<String>Concrete model selected for the review or judge phase, when required.
synthetic_model: StringSynthetic HydraFusion model selected for the session.
turn_id: StringIdentifier of the session turn associated with the route.