pub struct SessionSnapshotRewindData {
pub event_ids: Option<Vec<String>>,
pub events_removed: i64,
pub up_to_event_id: String,
}Expand description
Session event “session.snapshot_rewind”. Session rewind details including target event and count of removed events
Fields
event_ids: Option<Vec<String>>The removed events, starting with upToEventId. Later events not listed were kept, such as a background agent’s events that interleaved with a withdrawn turn
events_removed: i64Number of events that were removed by the rewind
up_to_event_id: StringFirst removed event. Without eventIds, it and every event after it were removed