pub type SessionIndexedSearchData = IndexedSearchData;Expand description
Session event “session.indexed_search”. Transient indexed-search status and diagnostics from the live runtime service. Never persisted or used to infer activation from session history.
Aliased Type
pub enum SessionIndexedSearchData {
Status(IndexedSearchDataStatus),
Startup(IndexedSearchDataStartup),
ServerError(IndexedSearchDataServerError),
Incremental(IndexedSearchDataIncremental),
}