pub fn convert_mcp_call_tool_result(value: &Value) -> Option<ToolResult>Expand description
Convert an MCP CallToolResult JSON value into a Copilot tool result.
Returns None when the value is not shaped like a CallToolResult.
pub fn convert_mcp_call_tool_result(value: &Value) -> Option<ToolResult>Convert an MCP CallToolResult JSON value into a Copilot tool result.
Returns None when the value is not shaped like a CallToolResult.