ContextTier

Enum ContextTier 

pub enum ContextTier {
    Default,
    LongContext,
    Unknown,
}
Context window tier for models that support tiered context windows. Context window tier for models that support tiered context windows. Context window tier for models that support tiered context windows. Allowed values for the ContextTier enumeration.

Variants



Default

Default context tier with standard context window size.



LongContext

Extended context tier with a larger context window.



Unknown

Unknown variant for forward compatibility.