pub enum PermissionDecision {
Show 15 variants
ApproveOnce(PermissionDecisionApproveOnce),
ApproveForSession(PermissionDecisionApproveForSession),
ApproveForLocation(PermissionDecisionApproveForLocation),
ApprovePermanently(PermissionDecisionApprovePermanently),
Reject(PermissionDecisionReject),
UserNotAvailable(PermissionDecisionUserNotAvailable),
Approved(PermissionDecisionApproved),
ApprovedForSession(PermissionDecisionApprovedForSession),
ApprovedForLocation(PermissionDecisionApprovedForLocation),
Cancelled(PermissionDecisionCancelled),
DeniedByRules(PermissionDecisionDeniedByRules),
DeniedNoApprovalRuleAndCouldNotRequestFromUser(PermissionDecisionDeniedNoApprovalRuleAndCouldNotRequestFromUser),
DeniedInteractivelyByUser(PermissionDecisionDeniedInteractivelyByUser),
DeniedByContentExclusionPolicy(PermissionDecisionDeniedByContentExclusionPolicy),
DeniedByPermissionRequestHook(PermissionDecisionDeniedByPermissionRequestHook),
}Expand description
Re-exports of generated protocol types that are part of the SDK’s
public API surface. The canonical definitions live in
crate::rpc; they live here so the crate-root
pub use types::* surfaces them alongside hand-written SDK types.
Re-exports of generated protocol types that are part of the SDK’s
public API surface. The canonical definitions live in
crate::rpc; they live here so the crate-root
pub use types::* surfaces them alongside hand-written SDK types.
Re-exports of generated protocol types that are part of the SDK’s
public API surface. The canonical definitions live in
crate::rpc; they live here so the crate-root
pub use types::* surfaces them alongside hand-written SDK types.
The client’s response to the pending permission prompt
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.