#[non_exhaustive]pub struct CloudSessionOptions {
pub repository: Option<CloudSessionRepository>,
}Expand description
Options for creating a remote session in the cloud.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository: Option<CloudSessionRepository>Optional GitHub repository metadata to associate with the cloud session.
Implementations
Sourceimpl CloudSessionOptions
impl CloudSessionOptions
Sourcepub fn with_repository(repository: CloudSessionRepository) -> Self
pub fn with_repository(repository: CloudSessionRepository) -> Self
Create cloud session options with repository metadata.