CommandDefinition

Struct CommandDefinition 

#[non_exhaustive]
pub struct CommandDefinition { pub name: String, pub description: Option<String>, pub handler: Arc<dyn CommandHandler>, }
Definition of a slash command registered with the session.

When the CLI is running with a TUI, registered commands appear as /name for the user to invoke. Only name and description are sent over the wire — the handler is local to this SDK process.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Command name (without leading /).

description: Option<String>

Human-readable description shown in command-completion UI.

handler: Arc<dyn CommandHandler>

Handler invoked when the command is executed.

Implementations

Source

impl CommandDefinition

pub fn new(name: impl Into<String>, handler: Arc<dyn CommandHandler>) -> Self

Construct a new command definition. Use with_description to add a description.

pub fn with_description(self, description: impl Into<String>) -> Self

Set the human-readable description shown in the CLI’s command-completion UI.