#[non_exhaustive]pub struct GitHubMcpToolConfig {
pub enable_all_tools: Option<bool>,
pub additional_toolsets: Option<Vec<String>>,
pub additional_tools: Option<Vec<String>>,
pub enable_insiders_mode: Option<bool>,
pub disable_form_deferral: Option<bool>,
}Expand description
Configuration for the built-in GitHub MCP server.
disable_form_deferral only applies to the built-in GitHub MCP server and
only has an effect when MCP Apps and form-backed GitHub tools are enabled.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_all_tools: Option<bool>Whether all GitHub MCP tools are enabled.
additional_toolsets: Option<Vec<String>>Additional GitHub MCP toolsets to enable.
additional_tools: Option<Vec<String>>Additional GitHub MCP tools to enable.
enable_insiders_mode: Option<bool>Whether GitHub MCP insiders mode is enabled.
disable_form_deferral: Option<bool>Disables form deferral for GitHub MCP tools. This only applies to the built-in GitHub MCP server and only has an effect when MCP Apps and form-backed GitHub tools are enabled.
Implementations
Sourceimpl GitHubMcpToolConfig
impl GitHubMcpToolConfig
Sourcepub fn with_enable_all_tools(self, value: bool) -> Self
pub fn with_enable_all_tools(self, value: bool) -> Self
Set whether all GitHub MCP tools are enabled.
Sourcepub fn with_additional_toolsets<I, S>(self, values: I) -> Self
pub fn with_additional_toolsets<I, S>(self, values: I) -> Self
Set the additional GitHub MCP toolsets to enable.
Sourcepub fn with_additional_tools<I, S>(self, values: I) -> Self
pub fn with_additional_tools<I, S>(self, values: I) -> Self
Set the additional GitHub MCP tools to enable.
Sourcepub fn with_enable_insiders_mode(self, value: bool) -> Self
pub fn with_enable_insiders_mode(self, value: bool) -> Self
Set whether GitHub MCP insiders mode is enabled.
Sourcepub fn with_disable_form_deferral(self, value: bool) -> Self
pub fn with_disable_form_deferral(self, value: bool) -> Self
Disable form deferral for GitHub MCP tools. This only applies to the built-in GitHub MCP server and only has an effect when MCP Apps and form-backed GitHub tools are enabled.