forward_http

Function forward_http 

pub async fn forward_http(
    request: CopilotHttpRequest,
) -> Result<CopilotHttpResponse, CopilotRequestError>
Forward an HTTP request to its real upstream and stream the response back.

This is the default behaviour of CopilotRequestHandler::send_request; consumers that mutate a request can call it to forward the mutated request.