pub struct SessionRpcAgent<'a> { /* private fields */ }Expand description
session.agent.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcAgent<'a>
impl<'a> SessionRpcAgent<'a>
Sourcepub async fn list(&self) -> Result<AgentList, Error>
pub async fn list(&self) -> Result<AgentList, Error>
Wire method: session.agent.list.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn get_current(&self) -> Result<AgentGetCurrentResult, Error>
pub async fn get_current(&self) -> Result<AgentGetCurrentResult, Error>
Wire method: session.agent.getCurrent.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn select(
&self,
params: AgentSelectRequest,
) -> Result<AgentSelectResult, Error>
pub async fn select( &self, params: AgentSelectRequest, ) -> Result<AgentSelectResult, Error>
Wire method: session.agent.select.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn deselect(&self) -> Result<(), Error>
pub async fn deselect(&self) -> Result<(), Error>
Wire method: session.agent.deselect.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn reload(&self) -> Result<AgentReloadResult, Error>
pub async fn reload(&self) -> Result<AgentReloadResult, Error>
Wire method: session.agent.reload.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.