pub struct SessionRpcExtensions<'a> { /* private fields */ }Expand description
session.extensions.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcExtensions<'a>
impl<'a> SessionRpcExtensions<'a>
Sourcepub async fn list(&self) -> Result<ExtensionList, Error>
pub async fn list(&self) -> Result<ExtensionList, Error>
Lists extensions discovered for the session and their current status.
Wire method: session.extensions.list.
Returns
Extensions discovered for the session, with their current status.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn enable(&self, params: ExtensionsEnableRequest) -> Result<(), Error>
pub async fn enable(&self, params: ExtensionsEnableRequest) -> Result<(), Error>
Enables an extension for the session.
Wire method: session.extensions.enable.
Parameters
params- Source-qualified extension identifier to enable for the session.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn disable(
&self,
params: ExtensionsDisableRequest,
) -> Result<(), Error>
pub async fn disable( &self, params: ExtensionsDisableRequest, ) -> Result<(), Error>
Disables an extension for the session.
Wire method: session.extensions.disable.
Parameters
params- Source-qualified extension identifier to disable for the session.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn reload(&self) -> Result<(), Error>
pub async fn reload(&self) -> Result<(), Error>
Reloads extension definitions and processes for the session.
Wire method: session.extensions.reload.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.