pub struct SessionRpcPlan<'a> { /* private fields */ }Expand description
session.plan.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcPlan<'a>
impl<'a> SessionRpcPlan<'a>
Sourcepub async fn read(&self) -> Result<PlanReadResult, Error>
pub async fn read(&self) -> Result<PlanReadResult, Error>
Reads the session plan file from the workspace.
Wire method: session.plan.read.
Returns
Existence, contents, and resolved path of the session plan file.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn update(&self, params: PlanUpdateRequest) -> Result<(), Error>
pub async fn update(&self, params: PlanUpdateRequest) -> Result<(), Error>
Writes new content to the session plan file.
Wire method: session.plan.update.
Parameters
params- Replacement contents to write to the session plan file.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn delete(&self) -> Result<(), Error>
pub async fn delete(&self) -> Result<(), Error>
Deletes the session plan file from the workspace.
Wire method: session.plan.delete.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.