pub struct SessionRpcSkills<'a> { /* private fields */ }Expand description
session.skills.* RPCs.
Implementations
Sourceimpl<'a> SessionRpcSkills<'a>
impl<'a> SessionRpcSkills<'a>
Sourcepub async fn list(&self) -> Result<SkillList, Error>
pub async fn list(&self) -> Result<SkillList, Error>
Wire method: session.skills.list.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn enable(&self, params: SkillsEnableRequest) -> Result<(), Error>
pub async fn enable(&self, params: SkillsEnableRequest) -> Result<(), Error>
Wire method: session.skills.enable.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.
Sourcepub async fn disable(&self, params: SkillsDisableRequest) -> Result<(), Error>
pub async fn disable(&self, params: SkillsDisableRequest) -> Result<(), Error>
Wire method: session.skills.disable.
Experimental. This API is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases. Pin both the SDK and CLI versions if your code depends on it.