pub enum CatalogTrustSnapshotUnsupportedStatus {
Unsupported,
Unknown,
}Expand description
The authority supplied a bounded trust value this runtime does not understand.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Variants
Unsupported
The authority supplied a bounded trust value this runtime does not understand.
Unknown
Unknown variant for forward compatibility.