pub struct AccountGetCurrentAuthResult {
pub auth_errors: Option<Vec<String>>,
pub auth_info: Option<AuthInfo>,
}Expand description
Current authentication state
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
auth_errors: Option<Vec<String>>Authentication errors from the last auth attempt, if any
auth_info: Option<AuthInfo>Current authentication information, if authenticated