pub struct ContentExclusionCheckPathsRequest {
pub paths: Vec<String>,
}Expand description
Local file system absolute paths within the session working directory to check against its content-exclusion policy.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
paths: Vec<String>Local file system absolute paths within the session working directory to check. Results are returned in the same order, including duplicates.