pub struct CopilotUserResponse {Show 25 fields
pub access_type_sku: Option<String>,
pub analytics_tracking_id: Option<String>,
pub assigned_date: Option<Value>,
pub can_signup_for_limited: Option<bool>,
pub can_upgrade_plan: Option<bool>,
pub chat_enabled: Option<bool>,
pub cli_remote_control_enabled: Option<bool>,
pub cloud_session_storage_enabled: Option<bool>,
pub codex_agent_enabled: Option<bool>,
pub copilot_plan: Option<String>,
pub copilotignore_enabled: Option<bool>,
pub endpoints: Option<CopilotUserResponseEndpoints>,
pub is_mcp_enabled: Option<Value>,
pub is_staff: Option<bool>,
pub limited_user_quotas: Option<HashMap<String, f64>>,
pub limited_user_reset_date: Option<String>,
pub login: Option<String>,
pub monthly_quotas: Option<HashMap<String, f64>>,
pub organization_list: Option<Value>,
pub organization_login_list: Option<Vec<String>>,
pub quota_reset_date: Option<String>,
pub quota_reset_date_utc: Option<String>,
pub quota_snapshots: Option<CopilotUserResponseQuotaSnapshots>,
pub restricted_telemetry: Option<bool>,
pub token_based_billing: Option<bool>,
}Expand description
Snapshot of the authenticated user’s Copilot subscription info, if known. Mirrors the GitHub API /copilot_internal/v2/token user response shape — the runtime trusts this verbatim and does not re-fetch when set.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
access_type_sku: Option<String>analytics_tracking_id: Option<String>assigned_date: Option<Value>can_signup_for_limited: Option<bool>can_upgrade_plan: Option<bool>chat_enabled: Option<bool>cli_remote_control_enabled: Option<bool>cloud_session_storage_enabled: Option<bool>codex_agent_enabled: Option<bool>copilot_plan: Option<String>copilotignore_enabled: Option<bool>endpoints: Option<CopilotUserResponseEndpoints>Schema for the CopilotUserResponseEndpoints type.
is_mcp_enabled: Option<Value>is_staff: Option<bool>limited_user_quotas: Option<HashMap<String, f64>>limited_user_reset_date: Option<String>login: Option<String>monthly_quotas: Option<HashMap<String, f64>>organization_list: Option<Value>organization_login_list: Option<Vec<String>>quota_reset_date: Option<String>quota_reset_date_utc: Option<String>quota_snapshots: Option<CopilotUserResponseQuotaSnapshots>Schema for the CopilotUserResponseQuotaSnapshots type.
restricted_telemetry: Option<bool>token_based_billing: Option<bool>Trait Implementations
Sourceimpl Clone for CopilotUserResponse
impl Clone for CopilotUserResponse
Sourcefn clone(&self) -> CopilotUserResponse
fn clone(&self) -> CopilotUserResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CopilotUserResponse
impl Debug for CopilotUserResponse
Sourceimpl Default for CopilotUserResponse
impl Default for CopilotUserResponse
Sourcefn default() -> CopilotUserResponse
fn default() -> CopilotUserResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CopilotUserResponse
impl<'de> Deserialize<'de> for CopilotUserResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more