pub struct FactoryAgentSummary {Show 13 fields
pub active_ms: i64,
pub activity: Option<String>,
pub agent_id: String,
pub agent_type: String,
pub completed_at: Option<i64>,
pub label: String,
pub phase_id: Option<String>,
pub requested_model: Option<String>,
pub resolved_model: Option<String>,
pub run_id: String,
pub started_at: Option<i64>,
pub status: String,
pub tool_call_id: String,
}Expand description
Prompt-safe durable identity and live status for a direct factory agent.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
active_ms: i64activity: Option<String>agent_id: Stringagent_type: Stringcompleted_at: Option<i64>label: Stringphase_id: Option<String>requested_model: Option<String>resolved_model: Option<String>run_id: Stringstarted_at: Option<i64>status: Stringtool_call_id: StringTrait Implementations
Sourceimpl Clone for FactoryAgentSummary
impl Clone for FactoryAgentSummary
Sourcefn clone(&self) -> FactoryAgentSummary
fn clone(&self) -> FactoryAgentSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FactoryAgentSummary
impl Debug for FactoryAgentSummary
Sourceimpl Default for FactoryAgentSummary
impl Default for FactoryAgentSummary
Sourcefn default() -> FactoryAgentSummary
fn default() -> FactoryAgentSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FactoryAgentSummary
impl<'de> Deserialize<'de> for FactoryAgentSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more