pub struct LlmInferenceSetProviderResult {
pub success: bool,
}Expand description
Indicates whether the calling client was registered as the LLM inference provider.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
success: boolWhether the provider was set successfully