pub struct McpServerConfigStdio {
pub args: Option<Vec<String>>,
pub auth: Option<Value>,
pub command: String,
pub cwd: Option<String>,
pub defer_tools: Option<McpServerConfigDeferTools>,
pub env: Option<HashMap<String, String>>,
pub filter_mapping: Option<Value>,
pub is_default_server: Option<bool>,
pub oidc: Option<Value>,
pub timeout: Option<i64>,
pub tools: Option<Vec<String>>,
}Expand description
Stdio MCP server configuration launched as a child process.
Fields
args: Option<Vec<String>>Command-line arguments passed to the Stdio MCP server process.
auth: Option<Value>Set to true to use defaults, or provide an object with additional auth or OIDC settings.
command: StringExecutable command used to start the Stdio MCP server process.
cwd: Option<String>Working directory for the Stdio MCP server process.
defer_tools: Option<McpServerConfigDeferTools>Controls if tools provided by this server can be loaded on demand via tool search (auto) or always included in the initial tool list (never)
env: Option<HashMap<String, String>>Environment variables to pass to the Stdio MCP server process.
filter_mapping: Option<Value>Content filtering mode to apply to all tools, or a map of tool name to content filtering mode.
is_default_server: Option<bool>Whether this server is a built-in fallback used when the user has not configured their own server.
oidc: Option<Value>Set to true to use defaults, or provide an object with additional auth or OIDC settings.
timeout: Option<i64>Timeout in milliseconds for tool calls to this server.
tools: Option<Vec<String>>Tools to include. Defaults to all tools if not specified.