pub struct QueuePendingItems {
pub display_text: String,
pub kind: QueuePendingItemsKind,
}Expand description
Schema for the QueuePendingItems type.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
display_text: StringHuman-readable text to display for this queue entry in the UI
kind: QueuePendingItemsKindWhether this item is a queued user message or a queued slash command / model change