pub struct RemoteControlStatusConnecting {
pub attached_session_id: String,
pub state: RemoteControlStatusConnectingState,
}Expand description
Remote control is in the middle of initial setup.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
attached_session_id: StringSession id the connection is attaching to.
state: RemoteControlStatusConnectingStateRemote control state tag: connecting.