pub struct SendMessageItem {
pub attachments: Option<Vec<Value>>,
pub display_prompt: Option<String>,
pub prompt: String,
pub required_tool: Option<String>,
/* private fields */
}Expand description
A single user message to append to the session as part of a session.sendMessages turn
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
attachments: Option<Vec<Value>>Optional attachments (files, directories, selections, blobs, GitHub references) to include with this message
display_prompt: Option<String>If provided, this is shown in the timeline instead of prompt
prompt: StringThe user message text
required_tool: Option<String>If set, the request will fail if the named tool is not available when this message is among the user messages at the start of the current exchange