pub struct SessionFsSetProviderRequest {
pub capabilities: Option<SessionFsSetProviderCapabilities>,
pub conventions: SessionFsSetProviderConventions,
pub initial_cwd: String,
pub session_state_path: String,
}Expand description
Initial working directory, session-state path layout, and path conventions used to register the calling SDK client as the session filesystem provider.
Fields
capabilities: Option<SessionFsSetProviderCapabilities>Optional capabilities declared by the provider
conventions: SessionFsSetProviderConventionsPath conventions used by this filesystem
initial_cwd: StringInitial working directory for sessions
session_state_path: StringPath within each session’s SessionFs where the runtime stores files for that session