pub struct SlashCommandModelPickerDialog {
pub kind: SlashCommandModelPickerDialogKind,
pub model_to_enable: Option<String>,
pub scope: Option<String>,
pub target: Option<String>,
}Expand description
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
kind: SlashCommandModelPickerDialogKindDiscriminator for a model-picker dialog.
model_to_enable: Option<String>Model that should be enabled before it can be selected.
scope: Option<String>Settings scope the picker should modify.
target: Option<String>Model-selection target represented by the picker.