pub struct UISessionLimitsExhaustedResponse {
pub action: UISessionLimitsExhaustedResponseAction,
pub additional_ai_credits: Option<f64>,
pub max_ai_credits: Option<f64>,
}Expand description
The user’s selected action for an exhausted session limit.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Fields
action: UISessionLimitsExhaustedResponseActionAction selected by the user.
additional_ai_credits: Option<f64>AI Credits to add to the current max when action is ‘add’.
max_ai_credits: Option<f64>New absolute max AI Credits when action is ‘set’.