LlmInferenceHeaders

Type Alias LlmInferenceHeaders 

pub type LlmInferenceHeaders = HashMap<String, Vec<String>>;
HTTP headers as a map from lowercased header name to a list of values. Multi-valued headers (e.g. Set-Cookie) preserve all values.

Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.

Aliased Type

pub struct LlmInferenceHeaders { /* private fields */ }