pub type SessionsGetClientMetadataResult = Vec<Value>;Expand description
Ordered client metadata outcomes for the requested local sessions.
Experimental. This type is part of an experimental wire-protocol surface and may change or be removed in future SDK or CLI releases.
Aliased Type
pub struct SessionsGetClientMetadataResult { /* private fields */ }