Session management — create, resume, send messages, and interact with the agent.
Structs
- Prepared
Session - A session that has been configured but not yet created on the CLI.
- Session
- A session on a GitHub Copilot CLI server.
- Session
Ui - UI sub-API for a
Session— elicitation, confirmation, selection, and free-form input.
Constants
- DEFAULT_
EVENT_ BUFFER_ CAPACITY - Default capacity of the per-session event broadcast buffer backing
Session::subscribeandPreparedSession::subscribe.